@@ -1,7 +1,7 @@
 /* ===EmacsMode: -*- Mode: C; tab-width:4; c-basic-offset: 4; -*- === */
 /* ===FileName: ===
    Copyright (c) 1998 Takuya SHIOZAKI, All Rights reserved.
-   Copyright (c) 1998 X-TrueType Server Project, All rights reserved. 
+   Copyright (c) 1998 X-TrueType Server Project, All rights reserved.
    Copyright (c) 2003 After X-TT Project, All rights reserved.
 
 ===Notice
@@ -30,7 +30,6 @@
 
 Notice===
  */
-/* $XFree86: xc/lib/font/FreeType/xttcap.c,v 1.1 2003/10/19 18:53:50 dawes Exp $ */
 
 /*
 #include "xttversion.h"
@@ -44,21 +43,8 @@ static char const * const releaseID =
 #endif
 #include <X11/fonts/fontmisc.h>
 #include <string.h>
-#ifndef FONTMODULE
 #include <ctype.h>
 #include <math.h>
-#else
-#include "Xmd.h"
-#include "Xdefs.h"
-#include "xf86_ansic.h"
-#endif
-/*
-#include <X11/X.h>
-#include <X11/Xmd.h>
-#include <X11/Xfuncproto.h>
-#include "xf86Module.h"
-#include "xf86_ansic.h"
-*/
 
 #ifndef True
 #define True (-1)
@@ -69,17 +55,6 @@ static char const * const releaseID =
 
 #include "xttcap.h"
 
-#if 0
-/*
-  Prototypes for obsoleted OS (e.g. SunOS4)
- */
-
-#if (defined(sun) && !(defined(SVR4) || defined(__SVR4)))
-double strtod(char *str, char **ptr);
-double strtol(char *str, char **ptr, int base);
-#endif
-#endif
-
 
 /**************************************************************************
   Private Data Types
@@ -158,7 +133,7 @@ get_record_type_by_name(SPropertyRecord const ** const refRefRecord, /*result*/
 {
     Bool result = False;
     int i;
-    
+
     *refRefRecord = NULL;
     for (i=0; i<numOfValidRecords; i++) {
         if (!strcasecmp(validRecords[i].strRecordName, strName)) {
@@ -167,7 +142,7 @@ get_record_type_by_name(SPropertyRecord const ** const refRefRecord, /*result*/
             break;
         }
     }
-    
+
     return result;
 }
 
@@ -186,7 +161,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
             {
                 int val;
                 char *endPtr;
-                    
+
                 val = strtol(strValue, &endPtr, 0);
                 if ('\0' != *endPtr) {
                     fprintf(stderr,
@@ -203,7 +178,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
             {
                 double val;
                 char *endPtr;
-                    
+
                 val = strtod(strValue, &endPtr);
                 if ('\0' != *endPtr) {
                     fprintf(stderr,
@@ -219,7 +194,7 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         case eRecTypeBool:
             {
                 Bool val;
-                
+
                 if (!strcasecmp(strValue, "yes"))
                     val = True;
                 else if (!strcasecmp(strValue, "y"))
@@ -258,15 +233,14 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         case eRecTypeString:
             {
                 char *p;
-                    
-                if (NULL == (p = (char *)xalloc(strlen(strValue)+1))) {
+
+                if (NULL == (p = strdup(strValue))) {
                     fprintf(stderr,
                             "truetype font property : "
                             "cannot allocate memory.\n");
                     result = True;
                     goto quit;
                 }
-                strcpy(p, strValue);
                 SPropContainer_value_str(&tmpContainerE) = p;
             }
             break;
@@ -282,9 +256,8 @@ SPropRecValList_add_record(SDynPropRecValList *pThisList,
         {
             /* add to list */
             SPropRecValListNodeP *newNode;
-            
-            if (NULL == (newNode =
-                         (SPropRecValListNodeP *)xalloc(sizeof(*newNode)))) {
+
+            if (NULL == (newNode = malloc(sizeof(*newNode)))) {
                 fprintf(stderr,
                         "truetype font property : "
                         "cannot allocate memory.\n");
@@ -327,11 +300,11 @@ get_one_line(FILE *is, char *buf)
     Bool flInDoubleQuote = False;
     Bool flBackSlash = False;
     Bool flFirstElement = True;
-    
+
     *buf = '\0';
     for (;;) {
         int c = fgetc(is);
-        
+
         if (ferror(is)) {
             fprintf(stderr, "truetype font property file : read error.\n");
             result = True;
@@ -472,8 +445,8 @@ parse_one_line(SDynPropRecValList *pThisList, FILE *is)
     Bool result = False;
     char *buf = NULL;
     char *recordHead, *valueHead = NULL;
-    
-    if (NULL == (buf = xalloc(LEN_LINEBUF))) {
+
+    if (NULL == (buf = malloc(LEN_LINEBUF))) {
         fprintf(stderr,
                 "truetype font property file : cannot allocate memory.\n");
         result = True;
@@ -508,8 +481,8 @@ parse_one_line(SDynPropRecValList *pThisList, FILE *is)
         result = SPropRecValList_add_record(pThisList, recordHead, valueHead);
     }
   quit:
-    xfree(buf);
-  abort:    
+    free(buf);
+  abort:
     return result;
 }
 
@@ -520,7 +493,7 @@ SPropRecValList_read_prop_file(SDynPropRecValList *pThisList,
 {
     Bool result = False;
     FILE *is;
-    
+
 #if 1
     if (!strcmp(strFileName, "-"))
         is = stdin;
@@ -556,7 +529,7 @@ Bool /* True == Error, False == Success */
 SPropRecValList_new(SDynPropRecValList *pThisList)
 {
     Bool result = False;
-    
+
     pThisList->headNode = NULL;
 
     return result;
@@ -608,7 +581,7 @@ SPropRecValList_search_record(SRefPropRecValList *pThisList,
 {
     Bool result = False;
     SPropRecValListNodeP *p;
-    
+
     *refRecValue = NULL;
     for (p=pThisList->headNode; NULL!=p; p=p->nextNode) {
         if (!strcasecmp(p->containerE.refRecordType->strRecordName,
@@ -631,7 +604,7 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
     Bool result = False;
     /*    SPropertyRecord const *refRecordType; */
     char const *term;
-    
+
     if (NULL == (term = strrchr(strCapHead, ':')))
         goto abort;
 
@@ -648,19 +621,18 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
                     int len = term-p-1;
                     char *value;
 
-                    len = term-p-1;
-                    value=(char *)xalloc(len+1);
+                    value=malloc(len+1);
                     memcpy(value, p+1, len);
                     value[len]='\0';
                     SPropRecValList_add_record(pThisList,
                                                "FaceNumber",
                                                value);
-                    xfree(value);
+                    free(value);
                     term=p;
                 }
                 break;
             }
-            if ( !isdigit(*p) )
+            if ( !isdigit((unsigned char)*p) )
                 break;
         }
     }
@@ -669,10 +641,10 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
         int i;
         char const *nextColon = strchr(strCapHead, ':');
         if (0<nextColon-strCapHead) {
-            char *duplicated = (char *)xalloc((nextColon-strCapHead)+1);
+            char *duplicated = malloc((nextColon-strCapHead)+1);
             {
                 char *value;
-            
+
                 memcpy(duplicated, strCapHead, nextColon-strCapHead);
                 duplicated[nextColon-strCapHead] = '\0';
                 if (NULL != (value=strchr(duplicated, '='))) {
@@ -680,7 +652,7 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
                     value++;
                 } else
                     value = &duplicated[nextColon-strCapHead];
-            
+
                 for (i=0; i<numOfCorrespondRelations; i++) {
                     if (!strcasecmp(correspondRelations[i].capVariable,
                                       duplicated)) {
@@ -698,34 +670,14 @@ SPropRecValList_add_by_font_cap(SDynPropRecValList *pThisList,
               next:
                 ;
             }
-            xfree(duplicated);
+            free(duplicated);
         }
         strCapHead = nextColon+1;
     }
-    
+
     /*  quit: */
   abort:
     return result;
 }
 
-
-/**************************************************************************
-  Functions (xttmisc)
- */
-
-/* strdup clone with using the allocator of X server */
-char *
-XttXstrdup(char const *str)
-{
-    char *result;
-    
-    result = (char *)xalloc(strlen(str)+1);
-
-    if (result)
-        strcpy(result, str);
-
-    return result;
-}
-
-
 /* end of file */
